{"": "", "Filter services": "\uc11c\ube44\uc2a4 \ud544\ud130", "Manager": "\uad00\ub9ac\uc790", "Service": "\uc11c\ube44\uc2a4", "Services": "\uc11c\ube44\uc2a4", "Manage system services": "\uc2dc\uc2a4\ud15c \uc11c\ube44\uc2a4 \uad00\ub9ac", "Service operation failed": "", "Done": ""}