{"": "", "Filter services": "\u7b5b\u9009\u5668\u670d\u52a1", "Manager": "\u7ba1\u7406\u5668", "Service": "\u670d\u52a1", "Services": "\u670d\u52a1", "Manage system services": "\u7ba1\u7406\u7cfb\u7edf\u670d\u52a1", "Service operation failed": "", "Done": ""}