{"": "", "Filter services": "Filtre hizmetleri", "Manager": "Y\u00f6netici", "Service": "Hizmet", "Services": "Hizmetler", "Manage system services": "Sistem hizmetlerini y\u00f6net", "Service operation failed": "", "Done": ""}